==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentagePriceOscillatorIndicatorDescription } from "./PercentagePriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PercentagePriceOscillatorIndicatorDescriptionMetadata.a == null) {
                PercentagePriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentagePriceOscillatorIndicatorDescriptionMetadata.c(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(PercentagePriceOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            PercentagePriceOscillatorIndicatorDescriptionMetadata.b(a);
            a.ad("PercentagePriceOscillatorIndicator", () => new PercentagePriceOscillatorIndicatorDescription());
            a.ac("PercentagePriceOscillatorIndicator", PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    PercentagePriceOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicatorDescriptionMetadata, 'PercentagePriceOscillatorIndicatorDescriptionMetadata');
    PercentagePriceOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentagePriceOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentagePriceOscillatorIndicatorDescription } from "./PercentagePriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PercentagePriceOscillatorIndicatorDescriptionMetadata.a == null) {
                PercentagePriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentagePriceOscillatorIndicatorDescriptionMetadata.c(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(PercentagePriceOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            PercentagePriceOscillatorIndicatorDescriptionMetadata.b(a);
            a.ae("PercentagePriceOscillatorIndicator", () => new PercentagePriceOscillatorIndicatorDescription());
            a.ad("PercentagePriceOscillatorIndicator", PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    PercentagePriceOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicatorDescriptionMetadata, 'PercentagePriceOscillatorIndicatorDescriptionMetadata');
    PercentagePriceOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentagePriceOscillatorIndicatorDescriptionMetadata;
})();
